@@ -21,6 +21,8 @@
 #
 import logging
 import warnings
+import urllib3
+import json
 from collections import defaultdict
 
 from requests import Session, utils
@@ -54,6 +56,7 @@ class CachedSchemaRegistryClient(object):
     Use CachedSchemaRegistryClient(dict: config) instead.
     Existing params ca_location, cert_location and key_location will be replaced with their librdkafka equivalents:
     `ssl.ca.location`, `ssl.certificate.location` and `ssl.key.location` respectively.
+    The support for password protected private key is via the Config only using 'ssl.key.password' field.
 
     Errors communicating to the server will result in a ClientError being raised.
 
@@ -109,6 +112,9 @@ class CachedSchemaRegistryClient(object):
         self.url = utils.urldefragauth(self.url)
 
         self._session = s
+        key_password = conf.pop('ssl.key.password', None)
+        self._is_key_password_provided = not key_password
+        self._https_session = self._make_https_session(s.cert[0], s.cert[1], ca_path, s.auth, key_password)
 
         self.auto_register_schemas = conf.pop("auto.register.schemas", True)
 
@@ -125,7 +131,32 @@ class CachedSchemaRegistryClient(object):
         self.close()
 
     def close(self):
-        self._session.close()
+        # Constructor exceptions may occur prior to _session being set.
+        if hasattr(self, '_session'):
+            self._session.close()
+        if hasattr(self, '_https_session'):
+            self._https_session.clear()
+
+    @staticmethod
+    def _make_https_session(cert_location, key_location, ca_certs_path, auth, key_password):
+        https_session = urllib3.PoolManager(cert_reqs='CERT_REQUIRED', ca_certs=ca_certs_path,
+                                            cert_file=cert_location, key_file=key_location, key_password=key_password)
+        https_session.auth = auth
+        return https_session
+
+    def _send_https_session_request(self, url, method, headers, body):
+        request_headers = {'Accept': ACCEPT_HDR}
+        auth = self._https_session.auth
+        if body:
+            body = json.dumps(body).encode('UTF-8')
+            request_headers["Content-Length"] = str(len(body))
+            request_headers["Content-Type"] = "application/vnd.schemaregistry.v1+json"
+        if auth[0] != '' and auth[1] != '':
+            request_headers.update(urllib3.make_headers(basic_auth=auth[0] + ":" +
+                                                        auth[1]))
+        request_headers.update(headers)
+        response = self._https_session.request(method, url, headers=request_headers, body=body)
+        return response
 
     @staticmethod
     def _configure_basic_auth(url, conf):
@@ -156,6 +187,13 @@ class CachedSchemaRegistryClient(object):
         if method not in VALID_METHODS:
             raise ClientError("Method {} is invalid; valid methods include {}".format(method, VALID_METHODS))
 
+        if url.startswith('https') and self._is_key_password_provided:
+            response = self._send_https_session_request(url, method, headers, body)
+            try:
+                return json.loads(response.data), response.status
+            except ValueError:
+                return response.content, response.status
+
         _headers = {'Accept': ACCEPT_HDR}
         if body:
             _headers["Content-Length"] = str(len(body))
