@@ -486,6 +486,7 @@ static PyObject *Consumer_commit (Handle *self, PyObject *args,
 	} else if (msg) {
 		Message *m;
                 PyObject *uo8;
+                rd_kafka_topic_partition_t *rktpar;
 
 		if (PyObject_Type((PyObject *)msg) !=
 		    (PyObject *)&MessageType) {
@@ -495,11 +496,24 @@ static PyObject *Consumer_commit (Handle *self, PyObject *args,
 		}
 
 		m = (Message *)msg;
+                
+                if (m->error != Py_None) {
+                        PyObject *error = Message_error(m, NULL);
+                        PyObject *errstr = PyObject_CallMethod(error, "str", NULL);
+                        cfl_PyErr_Format(RD_KAFKA_RESP_ERR__INVALID_ARG,
+                                         "Cannot commit offsets for message with error: '%s'" , PyUnicode_AsUTF8(errstr));
+                        Py_DECREF(error);
+                        Py_DECREF(errstr);
+                        return NULL;
+                }
 
 		c_offsets = rd_kafka_topic_partition_list_new(1);
-		rd_kafka_topic_partition_list_add(
-			c_offsets, cfl_PyUnistr_AsUTF8(m->topic, &uo8),
-			m->partition)->offset =m->offset + 1;
+		rktpar = rd_kafka_topic_partition_list_add(
+			        c_offsets, cfl_PyUnistr_AsUTF8(m->topic, &uo8),
+			        m->partition);
+                rktpar->offset =m->offset + 1;
+                rd_kafka_topic_partition_set_leader_epoch(rktpar,
+                        m->leader_epoch);
                 Py_XDECREF(uo8);
 
 	} else {
@@ -612,6 +626,7 @@ static PyObject *Consumer_store_offsets (Handle *self, PyObject *args,
 	} else {
 		Message *m;
 		PyObject *uo8;
+                rd_kafka_topic_partition_t *rktpar;
 
 		if (PyObject_Type((PyObject *)msg) !=
 		    (PyObject *)&MessageType) {
@@ -622,10 +637,23 @@ static PyObject *Consumer_store_offsets (Handle *self, PyObject *args,
 
 		m = (Message *)msg;
 
+                if (m->error != Py_None) {
+                        PyObject *error = Message_error(m, NULL);
+                        PyObject *errstr = PyObject_CallMethod(error, "str", NULL);
+                        cfl_PyErr_Format(RD_KAFKA_RESP_ERR__INVALID_ARG,
+                                         "Cannot store offsets for message with error: '%s'" , PyUnicode_AsUTF8(errstr));
+                        Py_DECREF(error);
+                        Py_DECREF(errstr);
+                        return NULL;
+                }
+
 		c_offsets = rd_kafka_topic_partition_list_new(1);
-		rd_kafka_topic_partition_list_add(
+		rktpar = rd_kafka_topic_partition_list_add(
 			c_offsets, cfl_PyUnistr_AsUTF8(m->topic, &uo8),
-			m->partition)->offset = m->offset + 1;
+			m->partition);
+                rktpar->offset = m->offset + 1;
+                rd_kafka_topic_partition_set_leader_epoch(rktpar,
+                        m->leader_epoch);
 		Py_XDECREF(uo8);
 	}
 
@@ -783,9 +811,11 @@ static PyObject *Consumer_resume (Handle *self, PyObject *args,
 static PyObject *Consumer_seek (Handle *self, PyObject *args, PyObject *kwargs) {
 
         TopicPartition *tp;
-        rd_kafka_resp_err_t err;
+        rd_kafka_resp_err_t err = RD_KAFKA_RESP_ERR_NO_ERROR;
         static char *kws[] = { "partition", NULL };
-        rd_kafka_topic_t *rkt;
+        rd_kafka_topic_partition_list_t *seek_partitions;
+        rd_kafka_topic_partition_t *rktpar;
+        rd_kafka_error_t *error;
 
         if (!self->rk) {
                 PyErr_SetString(PyExc_RuntimeError, "Consumer closed");
@@ -803,21 +833,26 @@ static PyObject *Consumer_seek (Handle *self, PyObject *args, PyObject *kwargs)
                 return NULL;
         }
 
-        rkt = rd_kafka_topic_new(self->rk, tp->topic, NULL);
-        if (!rkt) {
-                cfl_PyErr_Format(rd_kafka_last_error(),
-                                 "Failed to get topic object for "
-                                 "topic \"%s\": %s",
-                                 tp->topic,
-                                 rd_kafka_err2str(rd_kafka_last_error()));
-                return NULL;
-        }
+        seek_partitions = rd_kafka_topic_partition_list_new(1);
+        rktpar = rd_kafka_topic_partition_list_add(seek_partitions,
+                        tp->topic, tp->partition);
+        rktpar->offset = tp->offset;
+        rd_kafka_topic_partition_set_leader_epoch(rktpar, tp->leader_epoch);
 
         Py_BEGIN_ALLOW_THREADS;
-        err = rd_kafka_seek(rkt, tp->partition, tp->offset, -1);
+        error = rd_kafka_seek_partitions(self->rk, seek_partitions, -1);
         Py_END_ALLOW_THREADS;
 
-        rd_kafka_topic_destroy(rkt);
+        if (error) {
+                err = rd_kafka_error_code(error);
+                rd_kafka_error_destroy(error);
+        }
+
+        if (!err && seek_partitions->elems[0].err) {
+                err = seek_partitions->elems[0].err;
+        }
+
+        rd_kafka_topic_partition_list_destroy(seek_partitions);
 
         if (err) {
                 cfl_PyErr_Format(err,
@@ -970,8 +1005,8 @@ static PyObject *Consumer_poll (Handle *self, PyObject *args,
 
         msgobj = Message_new0(self, rkm);
 #ifdef RD_KAFKA_V_HEADERS
-        // Have to detach headers outside Message_new0 because it declares the
-        // rk message as a const
+        /** Have to detach headers outside Message_new0 because it declares the
+          * rk message as a const */
         rd_kafka_message_detach_headers(rkm, &((Message *)msgobj)->c_headers);
 #endif
         rd_kafka_message_destroy(rkm);
@@ -980,6 +1015,33 @@ static PyObject *Consumer_poll (Handle *self, PyObject *args,
 }
 
 
+static PyObject *Consumer_memberid (Handle *self, PyObject *args,
+                                    PyObject *kwargs) {
+        char *memberid;
+        PyObject *memberidobj;
+        if (!self->rk) {
+                PyErr_SetString(PyExc_RuntimeError,
+                                "Consumer closed");
+                return NULL;
+        }
+
+        memberid = rd_kafka_memberid(self->rk);
+
+        if (!memberid)
+                Py_RETURN_NONE;
+
+        if (!*memberid) {
+                rd_kafka_mem_free(self->rk, memberid);
+                Py_RETURN_NONE;
+        }
+
+        memberidobj = Py_BuildValue("s", memberid);
+        rd_kafka_mem_free(self->rk, memberid);
+
+        return memberidobj;
+}
+
+
 static PyObject *Consumer_consume (Handle *self, PyObject *args,
                                         PyObject *kwargs) {
         unsigned int num_messages = 1;
@@ -1035,8 +1097,8 @@ static PyObject *Consumer_consume (Handle *self, PyObject *args,
         for (i = 0; i < n; i++) {
                 PyObject *msgobj = Message_new0(self, rkmessages[i]);
 #ifdef RD_KAFKA_V_HEADERS
-                // Have to detach headers outside Message_new0 because it declares the
-                // rk message as a const
+                /** Have to detach headers outside Message_new0 because it declares the
+                  * rk message as a const */
                 rd_kafka_message_detach_headers(rkmessages[i], &((Message *)msgobj)->c_headers);
 #endif
                 PyList_SET_ITEM(msglist, i, msgobj);
@@ -1206,7 +1268,7 @@ static PyMethodDef Consumer_methods[] = {
         { "incremental_assign", (PyCFunction)Consumer_incremental_assign, METH_O,
           ".. py:function:: incremental_assign(partitions)\n"
           "\n"
-          "  Incrementally add the provided list of :py:class:`TopicPartition`s "
+          "  Incrementally add the provided list of :py:class:`TopicPartition` "
           "to the current partition assignment. This list must not contain "
           "duplicate entries, or any entry corresponding to an already "
           "assigned partition. When a COOPERATIVE assignor (i.e. incremental "
@@ -1409,6 +1471,19 @@ static PyMethodDef Consumer_methods[] = {
           "  :raises: RuntimeError if called on a closed consumer\n"
           "\n"
         },
+        { "memberid", (PyCFunction)Consumer_memberid, METH_NOARGS,
+          ".. py:function:: memberid()\n"
+          "\n"
+          " Return this client's broker-assigned group member id.\n"
+          "\n"
+          " The member id is assigned by the group coordinator and"
+          " is propagated to the consumer during rebalance.\n"
+          "\n"
+          "  :returns: Member id string or None\n"
+          "  :rtype: string\n"
+          "  :raises: RuntimeError if called on a closed consumer\n"
+          "\n"
+        },
 	{ "close", (PyCFunction)Consumer_close, METH_NOARGS,
 	  "\n"
 	  "  Close down and terminate the Kafka Consumer.\n"
@@ -1437,6 +1512,9 @@ static PyMethodDef Consumer_methods[] = {
           "send_offsets_to_transaction() API.\n"
           "\n"
         },
+        { "set_sasl_credentials", (PyCFunction)set_sasl_credentials, METH_VARARGS|METH_KEYWORDS,
+           set_sasl_credentials_doc
+        },
 
 
 	{ NULL }
