@@ -20,8 +20,6 @@
 
 """ Test script for confluent_kafka module """
 
-import confluent_kafka
-from confluent_kafka import admin
 import os
 import time
 import uuid
@@ -29,6 +27,13 @@ import sys
 import json
 import gc
 import struct
+import re
+import pytest
+
+import confluent_kafka
+
+from tests.common import TestConsumer
+from tests.common.schema_registry import TestAvroConsumer
 
 try:
     # Memory tracker
@@ -209,6 +214,7 @@ def verify_producer():
 DrOnlyTestSuccess_gced = 0
 
 
+@pytest.mark.skip(reason="This test must be run as a standalone script")
 def test_producer_dr_only_error():
     """
     The C delivery.report.only.error configuration property
@@ -262,7 +268,6 @@ def test_producer_dr_only_error():
     # since there is a on_delivery reference to it.
     not_called_state = None
     gc.collect()
-    global DrOnlyTestSuccess_gced
     assert DrOnlyTestSuccess_gced == 0
 
     print('only.error: Waiting for flush of %d messages' % len(p))
@@ -330,9 +335,9 @@ def verify_producer_performance(with_dr_cb=True):
         bar.finish()
 
     print('# producing %d messages (%.2fMb) took %.3fs: %d msgs/s, %.2f Mb/s' %
-          (msgs_produced, bytecnt / (1024*1024), t_produce_spent,
+          (msgs_produced, bytecnt / (1024 * 1024), t_produce_spent,
            msgs_produced / t_produce_spent,
-           (bytecnt/t_produce_spent) / (1024*1024)))
+           (bytecnt / t_produce_spent) / (1024 * 1024)))
     print('# %d temporary produce() failures due to backpressure (local queue full)' % msgs_backpressure)
 
     print('waiting for %d/%d deliveries' % (len(p), msgs_produced))
@@ -341,9 +346,9 @@ def verify_producer_performance(with_dr_cb=True):
     t_delivery_spent = time.time() - t_produce_start
 
     print('# producing %d messages (%.2fMb) took %.3fs: %d msgs/s, %.2f Mb/s' %
-          (msgs_produced, bytecnt / (1024*1024), t_produce_spent,
+          (msgs_produced, bytecnt / (1024 * 1024), t_produce_spent,
            msgs_produced / t_produce_spent,
-           (bytecnt/t_produce_spent) / (1024*1024)))
+           (bytecnt / t_produce_spent) / (1024 * 1024)))
 
     # Fake numbers if not using a dr_cb
     if not with_dr_cb:
@@ -352,9 +357,9 @@ def verify_producer_performance(with_dr_cb=True):
         dr.bytes_delivered = bytecnt
 
     print('# delivering %d messages (%.2fMb) took %.3fs: %d msgs/s, %.2f Mb/s' %
-          (dr.msgs_delivered, dr.bytes_delivered / (1024*1024), t_delivery_spent,
+          (dr.msgs_delivered, dr.bytes_delivered / (1024 * 1024), t_delivery_spent,
            dr.msgs_delivered / t_delivery_spent,
-           (dr.bytes_delivered/t_delivery_spent) / (1024*1024)))
+           (dr.bytes_delivered / t_delivery_spent) / (1024 * 1024)))
     print('# post-produce delivery wait took %.3fs' %
           (t_delivery_spent - t_produce_spent))
 
@@ -373,7 +378,7 @@ def verify_consumer():
             'enable.partition.eof': True}
 
     # Create consumer
-    c = confluent_kafka.Consumer(conf)
+    c = TestConsumer(conf)
 
     def print_wmark(consumer, topic_parts):
         # Verify #294: get_watermark_offsets() should not fail on the first call
@@ -444,7 +449,7 @@ def verify_consumer():
         elif (msg.offset() % 4) == 0:
             offsets = c.commit(msg, asynchronous=False)
             assert len(offsets) == 1, 'expected 1 offset, not %s' % (offsets)
-            assert offsets[0].offset == msg.offset()+1, \
+            assert offsets[0].offset == msg.offset() + 1, \
                 'expected offset %d to be committed, not %s' % \
                 (msg.offset(), offsets)
             print('Sync committed offset: %s' % offsets)
@@ -483,7 +488,7 @@ def verify_consumer():
     c.close()
 
     # Start a new client and get the committed offsets
-    c = confluent_kafka.Consumer(conf)
+    c = TestConsumer(conf)
     offsets = c.committed(list(map(lambda p: confluent_kafka.TopicPartition(topic, p), range(0, 3))))
     for tp in offsets:
         print(tp)
@@ -500,7 +505,7 @@ def verify_consumer_performance():
             'error_cb': error_cb,
             'auto.offset.reset': 'earliest'}
 
-    c = confluent_kafka.Consumer(conf)
+    c = TestConsumer(conf)
 
     def my_on_assign(consumer, partitions):
         print('on_assign:', len(partitions), 'partitions:')
@@ -512,7 +517,7 @@ def verify_consumer_performance():
         print('on_revoke:', len(partitions), 'partitions:')
         for p in partitions:
             print(' %s [%d] @ %d' % (p.topic, p.partition, p.offset))
-        consumer.unassign()
+        consumer.unassign(partitions)
 
     c.subscribe([topic], on_assign=my_on_assign, on_revoke=my_on_revoke)
 
@@ -556,8 +561,8 @@ def verify_consumer_performance():
     if msgcnt > 0:
         t_spent = time.time() - t_first_msg
         print('%d messages (%.2fMb) consumed in %.3fs: %d msgs/s, %.2f Mb/s' %
-              (msgcnt, bytecnt / (1024*1024), t_spent, msgcnt / t_spent,
-               (bytecnt / t_spent) / (1024*1024)))
+              (msgcnt, bytecnt / (1024 * 1024), t_spent, msgcnt / t_spent,
+               (bytecnt / t_spent) / (1024 * 1024)))
 
     print('closing consumer')
     c.close()
@@ -569,7 +574,8 @@ def verify_consumer_seek(c, seek_to_msg):
 
     tp = confluent_kafka.TopicPartition(seek_to_msg.topic(),
                                         seek_to_msg.partition(),
-                                        seek_to_msg.offset())
+                                        seek_to_msg.offset(),
+                                        leader_epoch=seek_to_msg.leader_epoch())
     print('seek: Seeking to %s' % tp)
     c.seek(tp)
 
@@ -583,9 +589,14 @@ def verify_consumer_seek(c, seek_to_msg):
         if msg.topic() != seek_to_msg.topic() or msg.partition() != seek_to_msg.partition():
             continue
 
-        print('seek: message at offset %d' % msg.offset())
-        assert msg.offset() == seek_to_msg.offset(), \
-            'expected message at offset %d, not %d' % (seek_to_msg.offset(), msg.offset())
+        print('seek: message at offset %d (epoch %d)' %
+              (msg.offset(), msg.leader_epoch()))
+        assert msg.offset() == seek_to_msg.offset() and \
+            msg.leader_epoch() == seek_to_msg.leader_epoch(), \
+            ('expected message at offset %d (epoch %d), ' % (seek_to_msg.offset(),
+                                                             seek_to_msg.leader_epoch())) + \
+            ('not %d (epoch %d)' % (msg.offset(),
+                                    msg.leader_epoch()))
         break
 
 
@@ -602,7 +613,7 @@ def verify_batch_consumer():
             'auto.offset.reset': 'earliest'}
 
     # Create consumer
-    c = confluent_kafka.Consumer(conf)
+    c = TestConsumer(conf)
 
     # Subscribe to a list of topics
     c.subscribe([topic])
@@ -634,7 +645,7 @@ def verify_batch_consumer():
             elif (msg.offset() % 4) == 0:
                 offsets = c.commit(msg, asynchronous=False)
                 assert len(offsets) == 1, 'expected 1 offset, not %s' % (offsets)
-                assert offsets[0].offset == msg.offset()+1, \
+                assert offsets[0].offset == msg.offset() + 1, \
                     'expected offset %d to be committed, not %s' % \
                     (msg.offset(), offsets)
                 print('Sync committed offset: %s' % offsets)
@@ -659,7 +670,7 @@ def verify_batch_consumer():
     c.close()
 
     # Start a new client and get the committed offsets
-    c = confluent_kafka.Consumer(conf)
+    c = TestConsumer(conf)
     offsets = c.committed(list(map(lambda p: confluent_kafka.TopicPartition(topic, p), range(0, 3))))
     for tp in offsets:
         print(tp)
@@ -676,7 +687,7 @@ def verify_batch_consumer_performance():
             'error_cb': error_cb,
             'auto.offset.reset': 'earliest'}
 
-    c = confluent_kafka.Consumer(conf)
+    c = TestConsumer(conf)
 
     def my_on_assign(consumer, partitions):
         print('on_assign:', len(partitions), 'partitions:')
@@ -688,7 +699,7 @@ def verify_batch_consumer_performance():
         print('on_revoke:', len(partitions), 'partitions:')
         for p in partitions:
             print(' %s [%d] @ %d' % (p.topic, p.partition, p.offset))
-        consumer.unassign()
+        consumer.unassign(partitions)
 
     c.subscribe([topic], on_assign=my_on_assign, on_revoke=my_on_revoke)
 
@@ -729,8 +740,8 @@ def verify_batch_consumer_performance():
     if msgcnt > 0:
         t_spent = time.time() - t_first_msg
         print('%d messages (%.2fMb) consumed in %.3fs: %d msgs/s, %.2f Mb/s' %
-              (msgcnt, bytecnt / (1024*1024), t_spent, msgcnt / t_spent,
-               (bytecnt / t_spent) / (1024*1024)))
+              (msgcnt, bytecnt / (1024 * 1024), t_spent, msgcnt / t_spent,
+               (bytecnt / t_spent) / (1024 * 1024)))
 
     print('closing consumer')
     c.close()
@@ -796,13 +807,17 @@ def verify_avro_basic_auth(mode_conf):
     if mode_conf is None:
         abort_on_missing_configuration('avro-basic-auth')
 
-    url = {
-        'schema.registry.basic.auth.credentials.source': 'URL'
+    url = mode_conf.get('schema.registry.url')
+    credentials = mode_conf.get('schema.registry.basic.auth.user.info')
+
+    url_conf = {
+        'schema.registry.basic.auth.credentials.source': 'URL',
+        'schema.registry.url': str(re.sub("(^https?://)", f"\\1{credentials}@", url))
     }
 
     user_info = {
         'schema.registry.basic.auth.credentials.source': 'USER_INFO',
-        'schema.registry.basic.auth.user.info': mode_conf.get('schema.registry.basic.auth.user.info')
+        'schema.registry.basic.auth.user.info': credentials
     }
 
     sasl_inherit = {
@@ -812,10 +827,10 @@ def verify_avro_basic_auth(mode_conf):
     }
 
     base_conf = {
-            'bootstrap.servers': bootstrap_servers,
-            'error_cb': error_cb,
-            'schema.registry.url': schema_registry_url
-            }
+        'bootstrap.servers': bootstrap_servers,
+        'error_cb': error_cb,
+        'schema.registry.url': url
+    }
 
     consumer_conf = dict({'group.id': generate_group_id(),
                           'session.timeout.ms': 6000,
@@ -830,7 +845,7 @@ def verify_avro_basic_auth(mode_conf):
     run_avro_loop(dict(base_conf, **sasl_inherit), dict(consumer_conf, **sasl_inherit))
 
     print('-' * 10, 'Verifying basic auth source URL', '-' * 10)
-    run_avro_loop(dict(base_conf, **url), dict(consumer_conf, **url))
+    run_avro_loop(dict(base_conf, **url_conf), dict(consumer_conf, **url_conf))
 
 
 def run_avro_loop(producer_conf, consumer_conf):
@@ -867,7 +882,7 @@ def run_avro_loop(producer_conf, consumer_conf):
         p.produce(**combo)
     p.flush()
 
-    c = avro.AvroConsumer(consumer_conf)
+    c = TestAvroConsumer(consumer_conf)
     c.subscribe([(t['topic']) for t in combinations])
 
     msgcount = 0
@@ -979,7 +994,7 @@ def verify_stats_cb():
             'statistics.interval.ms': 200,
             'auto.offset.reset': 'earliest'}
 
-    c = confluent_kafka.Consumer(conf)
+    c = TestConsumer(conf)
     c.subscribe([topic])
 
     max_msgcnt = 1000000
@@ -1022,14 +1037,14 @@ def verify_stats_cb():
     if msgcnt > 0:
         t_spent = time.time() - t_first_msg
         print('%d messages (%.2fMb) consumed in %.3fs: %d msgs/s, %.2f Mb/s' %
-              (msgcnt, bytecnt / (1024*1024), t_spent, msgcnt / t_spent,
-               (bytecnt / t_spent) / (1024*1024)))
+              (msgcnt, bytecnt / (1024 * 1024), t_spent, msgcnt / t_spent,
+               (bytecnt / t_spent) / (1024 * 1024)))
 
     print('closing consumer')
     c.close()
 
 
-def verify_topic_metadata(client, exp_topics):
+def verify_topic_metadata(client, exp_topics, *args, **kwargs):
     """
     Verify that exp_topics (dict<topicname,partcnt>) is reported in metadata.
     Will retry and wait for some time to let changes propagate.
@@ -1041,7 +1056,7 @@ def verify_topic_metadata(client, exp_topics):
     for retry in range(0, 3):
         do_retry = 0
 
-        md = client.list_topics()
+        md = client.list_topics(*args, **kwargs)
 
         for exptopic, exppartcnt in exp_topics.items():
             if exptopic not in md.topics:
@@ -1067,157 +1082,6 @@ def verify_topic_metadata(client, exp_topics):
     raise Exception("Timed out waiting for topics {} in metadata".format(exp_topics))
 
 
-def verify_admin():
-    """ Verify Admin API """
-
-    a = admin.AdminClient({'bootstrap.servers': bootstrap_servers})
-    our_topic = topic + '_admin_' + str(uuid.uuid4())
-    num_partitions = 2
-
-    topic_config = {"compression.type": "gzip"}
-
-    #
-    # First iteration: validate our_topic creation.
-    # Second iteration: create topic.
-    #
-    for validate in (True, False):
-        fs = a.create_topics([admin.NewTopic(our_topic,
-                                             num_partitions=num_partitions,
-                                             config=topic_config,
-                                             replication_factor=1)],
-                             validate_only=validate,
-                             operation_timeout=10.0)
-
-        for topic2, f in fs.items():
-            f.result()  # trigger exception if there was an error
-
-    #
-    # Find the topic in list_topics
-    #
-    verify_topic_metadata(a, {our_topic: num_partitions})
-
-    #
-    # Increase the partition count
-    #
-    num_partitions += 3
-    fs = a.create_partitions([admin.NewPartitions(our_topic,
-                                                  new_total_count=num_partitions)],
-                             operation_timeout=10.0)
-
-    for topic2, f in fs.items():
-        f.result()  # trigger exception if there was an error
-
-    #
-    # Verify with list_topics.
-    #
-    verify_topic_metadata(a, {our_topic: num_partitions})
-
-    #
-    # Verify with list_groups.
-    #
-
-    # Produce some messages
-    p = confluent_kafka.Producer({"bootstrap.servers": bootstrap_servers})
-    p.produce(our_topic, 'Hello Python!', headers=produce_headers)
-    p.produce(our_topic, key='Just a key and headers', headers=produce_headers)
-
-    def consume_messages(group_id):
-        # Consume messages
-        conf = {'bootstrap.servers': bootstrap_servers,
-                'group.id': group_id,
-                'session.timeout.ms': 6000,
-                'enable.auto.commit': False,
-                'on_commit': print_commit_result,
-                'error_cb': error_cb,
-                'auto.offset.reset': 'earliest',
-                'enable.partition.eof': True}
-        c = confluent_kafka.Consumer(conf)
-        c.subscribe([our_topic])
-        eof_reached = dict()
-        while True:
-            msg = c.poll()
-            if msg is None:
-                raise Exception('Got timeout from poll() without a timeout set: %s' % msg)
-
-            if msg.error():
-                if msg.error().code() == confluent_kafka.KafkaError._PARTITION_EOF:
-                    print('Reached end of %s [%d] at offset %d' % (
-                          msg.topic(), msg.partition(), msg.offset()))
-                    eof_reached[(msg.topic(), msg.partition())] = True
-                    if len(eof_reached) == len(c.assignment()):
-                        print('EOF reached for all assigned partitions: exiting')
-                        break
-                else:
-                    print('Consumer error: %s: ignoring' % msg.error())
-                    break
-            # Commit offset
-            c.commit(msg, asynchronous=False)
-
-    group1 = 'test-group-1'
-    group2 = 'test-group-2'
-    consume_messages(group1)
-    consume_messages(group2)
-    # list_groups without group argument
-    groups = set(group.id for group in a.list_groups(timeout=10))
-    assert group1 in groups, "Consumer group {} not found".format(group1)
-    assert group2 in groups, "Consumer group {} not found".format(group2)
-    # list_groups with group argument
-    groups = set(group.id for group in a.list_groups(group1))
-    assert group1 in groups, "Consumer group {} not found".format(group1)
-    groups = set(group.id for group in a.list_groups(group2))
-    assert group2 in groups, "Consumer group {} not found".format(group2)
-
-    def verify_config(expconfig, configs):
-        """
-        Verify that the config key,values in expconfig are found
-        and matches the ConfigEntry in configs.
-        """
-        for key, expvalue in expconfig.items():
-            entry = configs.get(key, None)
-            assert entry is not None, "Config {} not found in returned configs".format(key)
-
-            assert entry.value == str(expvalue), \
-                "Config {} with value {} does not match expected value {}".format(key, entry, expvalue)
-
-    #
-    # Get current topic config
-    #
-    resource = admin.ConfigResource(admin.RESOURCE_TOPIC, our_topic)
-    fs = a.describe_configs([resource])
-    configs = fs[resource].result()  # will raise exception on failure
-
-    # Verify config matches our expectations
-    verify_config(topic_config, configs)
-
-    #
-    # Now change the config.
-    #
-    topic_config["file.delete.delay.ms"] = 12345
-    topic_config["compression.type"] = "snappy"
-
-    for key, value in topic_config.items():
-        resource.set_config(key, value)
-
-    fs = a.alter_configs([resource])
-    fs[resource].result()  # will raise exception on failure
-
-    #
-    # Read the config back again and verify.
-    #
-    fs = a.describe_configs([resource])
-    configs = fs[resource].result()  # will raise exception on failure
-
-    # Verify config matches our expectations
-    verify_config(topic_config, configs)
-
-    #
-    # Delete the topic
-    #
-    fs = a.delete_topics([our_topic])
-    fs[our_topic].result()  # will raise exception on failure
-    print("Topic {} marked for deletion".format(our_topic))
-
-
 def verify_avro_explicit_read_schema():
     from confluent_kafka import avro
 
@@ -1257,7 +1121,7 @@ def verify_avro_explicit_read_schema():
         p.produce(topic=avro_topic, **combo)
     p.flush()
 
-    c = avro.AvroConsumer(consumer_conf, reader_key_schema=reader_schema, reader_value_schema=reader_schema)
+    c = TestAvroConsumer(consumer_conf, reader_key_schema=reader_schema, reader_value_schema=reader_schema)
     c.subscribe([avro_topic])
 
     msgcount = 0
@@ -1273,10 +1137,10 @@ def verify_avro_explicit_read_schema():
         msgcount += 1
         # Avro schema projection should return the two fields not present in the writer schema
         try:
-            assert(msg.key().get('favorite_number') == 42)
-            assert(msg.key().get('favorite_color') == "purple")
-            assert(msg.value().get('favorite_number') == 42)
-            assert(msg.value().get('favorite_color') == "purple")
+            assert (msg.key().get('favorite_number') == 42)
+            assert (msg.key().get('favorite_color') == "purple")
+            assert (msg.value().get('favorite_number') == 42)
+            assert (msg.value().get('favorite_color') == "purple")
             print("success: schema projection worked for explicit reader schema")
         except KeyError:
             raise confluent_kafka.avro.SerializerError("Schema projection failed when setting reader schema.")
@@ -1401,15 +1265,21 @@ if __name__ == '__main__':
     if 'avro-https' in modes:
         print('=' * 30, 'Verifying AVRO with HTTPS', '=' * 30)
         verify_avro_https(testconf.get('avro-https', None))
+        key_with_password_conf = testconf.get("avro-https-key-with-password", None)
+        print('=' * 30, 'Verifying AVRO with HTTPS Flow with Password',
+              'Protected Private Key of Cached-Schema-Registry-Client', '=' * 30)
+        verify_avro_https(key_with_password_conf)
+        print('Verifying Error with Wrong Password of Password Protected Private Key of Cached-Schema-Registry-Client')
+        try:
+            key_with_password_conf['schema.registry.ssl.key.password'] += '->wrongpassword'
+            verify_avro_https(key_with_password_conf)
+        except Exception:
+            print("Wrong Password Gives Error -> Successful")
 
     if 'avro-basic-auth' in modes:
         print("=" * 30, 'Verifying AVRO with Basic Auth', '=' * 30)
         verify_avro_basic_auth(testconf.get('avro-basic-auth', None))
 
-    if 'admin' in modes:
-        print('=' * 30, 'Verifying Admin API', '=' * 30)
-        verify_admin()
-
     print('=' * 30, 'Done', '=' * 30)
 
     if with_pympler:
