@@ -4,7 +4,7 @@ import pytest
 
 from confluent_kafka import (Consumer, TopicPartition, KafkaError,
                              KafkaException, TIMESTAMP_NOT_AVAILABLE,
-                             OFFSET_INVALID, libversion)
+                             OFFSET_INVALID)
 
 from tests.common import TestConsumer
 
@@ -117,8 +117,6 @@ def test_basic_api():
     kc.close()
 
 
-@pytest.mark.skipif(libversion()[1] < 0x000b0000,
-                    reason="requires librdkafka >=0.11.0")
 def test_store_offsets():
     """ Basic store_offsets() tests """
 
@@ -139,10 +137,6 @@ def test_store_offsets():
     c.close()
 
 
-# librdkafka <=0.9.2 has a race-issue where it will hang indefinately
-# if a commit is issued when no coordinator is available.
-@pytest.mark.skipif(libversion()[1] <= 0x000902ff,
-                    reason="requires librdkafka >0.9.2")
 def test_on_commit():
     """ Verify that on_commit is only called once per commit() (issue #71) """
 
@@ -196,8 +190,6 @@ def test_subclassing():
     sc.close()
 
 
-@pytest.mark.skipif(libversion()[1] < 0x000b0000,
-                    reason="requires librdkafka >=0.11.0")
 def test_offsets_for_times():
     c = TestConsumer({'group.id': 'test',
                       'enable.auto.commit': True,
@@ -294,8 +286,6 @@ def test_any_method_after_close_throws_exception():
     assert ex.match('Consumer closed')
 
 
-@pytest.mark.skipif(libversion()[1] < 0x000b0000,
-                    reason="requires librdkafka >=0.11.0")
 def test_calling_store_offsets_after_close_throws_erro():
     """ calling store_offset after close should throw RuntimeError """
 
