@@ -14,17 +14,11 @@ from tests.common import TestConsumer
 
 
 def test_version():
-    print('Using confluent_kafka module version %s (0x%x)' % confluent_kafka.version())
-    sver, iver = confluent_kafka.version()
-    assert len(sver) > 0
-    assert iver > 0
+    print('Using confluent_kafka module version %s' % confluent_kafka.version())
+    assert len(confluent_kafka.version()) > 0
 
-    print('Using librdkafka version %s (0x%x)' % confluent_kafka.libversion())
-    sver, iver = confluent_kafka.libversion()
-    assert len(sver) > 0
-    assert iver > 0
-
-    assert confluent_kafka.version()[0] == confluent_kafka.__version__
+    print('Using librdkafka version (%s, %i)' % confluent_kafka.libversion())
+    assert len(confluent_kafka.libversion()[0]) > 0
 
 
 def test_error_cb():
